## Purpose 
This module will connect to the specified DC/OS Master (or https://master.mesos/ if no cluster URL is specified) and with the given username/key or username/password, get a JWT that is valid for the specified amount of time. 

## Usage

